@@ -15,9 +15,14 @@ from testflows._core.cli.arg.common import epilog
 from testflows._core.cli.arg.common import HelpFormatter
 from testflows._core.cli.arg.handlers.handler import Handler as HandlerBase
 from testflows._core.cli.arg.handlers.report.srs_coverage import Handler as srs_coverage_handler
+from testflows._core.cli.arg.handlers.report.passing import Handler as passing_handler
 from testflows._core.cli.arg.handlers.report.totals import Handler as totals_handler
 from testflows._core.cli.arg.handlers.report.fails import Handler as fails_handler
 from testflows._core.cli.arg.handlers.report.version import Handler as version_handler
+from testflows._core.cli.arg.handlers.report.official import Handler as official_handler
+from testflows._core.cli.arg.handlers.report.compare import Handler as compare_handler
+from testflows._core.cli.arg.handlers.report.requirements import Handler as requirements_handler
+from testflows._core.cli.arg.handlers.report.map.handler import Handler as map_handler
 
 class Handler(HandlerBase):
     @classmethod
@@ -29,7 +34,12 @@ class Handler(HandlerBase):
         report_commands = parser.add_subparsers(title="commands", metavar="command",
             description=None, help=None)
         report_commands.required = True
-        srs_coverage_handler.add_command(report_commands)
+        official_handler.add_command(report_commands)
+        compare_handler.add_command(report_commands)
         totals_handler.add_command(report_commands)
+        passing_handler.add_command(report_commands)
         fails_handler.add_command(report_commands)
         version_handler.add_command(report_commands)
+        requirements_handler.add_command(report_commands)
+        srs_coverage_handler.add_command(report_commands)
+        map_handler.add_command(report_commands)
